@@ -67,8 +67,9 @@ class AppendReplaceDefault(argparse.Action):
 def _add_hook_type_option(parser: argparse.ArgumentParser) -> None:
     parser.add_argument(
         '-t', '--hook-type', choices=(
-            'pre-commit', 'pre-merge-commit', 'pre-push',
-            'prepare-commit-msg', 'commit-msg', 'post-commit', 'post-checkout',
+            'pre-commit', 'pre-merge-commit', 'pre-push', 'prepare-commit-msg',
+            'commit-msg', 'post-commit', 'post-checkout', 'post-merge',
+            'post-rewrite',
         ),
         action=AppendReplaceDefault,
         default=['pre-commit'],
@@ -99,6 +100,9 @@ def _add_run_options(parser: argparse.ArgumentParser) -> None:
     parser.add_argument(
         '--remote-branch', help='Remote branch ref used by `git push`.',
     )
+    parser.add_argument(
+        '--local-branch', help='Local branch ref used by `git push`.',
+    )
     parser.add_argument(
         '--from-ref', '--source', '-s',
         help=(
@@ -136,6 +140,20 @@ def _add_run_options(parser: argparse.ArgumentParser) -> None:
             'file from the index, flag=0).'
         ),
     )
+    parser.add_argument(
+        '--is-squash-merge',
+        help=(
+            'During a post-merge hook, indicates whether the merge was a '
+            'squash merge'
+        ),
+    )
+    parser.add_argument(
+        '--rewrite-command',
+        help=(
+            'During a post-rewrite hook, specifies the command that invoked '
+            'the rewrite'
+        ),
+    )
 
 
 def _adjust_args_and_chdir(args: argparse.Namespace) -> None:
@@ -393,4 +411,4 @@ def main(argv: Optional[Sequence[str]] = None) -> int:
 
 
 if __name__ == '__main__':
-    exit(main())
+    raise SystemExit(main())
