@@ -48,6 +48,10 @@ skipif_cant_run_docker = pytest.mark.skipif(
     os.name == 'nt' or not docker_is_running(),
     reason="Docker isn't running or can't be accessed",
 )
+skipif_cant_run_lua = pytest.mark.skipif(
+    os.name == 'nt',
+    reason="lua isn't installed or can't be found",
+)
 skipif_cant_run_swift = pytest.mark.skipif(
     parse_shebang.find_executable('swift') is None,
     reason="swift isn't installed or can't be found",
@@ -62,6 +66,7 @@ def run_opts(
         verbose=False,
         hook=None,
         remote_branch='',
+        local_branch='',
         from_ref='',
         to_ref='',
         remote_name='',
@@ -70,6 +75,8 @@ def run_opts(
         show_diff_on_failure=False,
         commit_msg_filename='',
         checkout_type='',
+        is_squash_merge='',
+        rewrite_command='',
 ):
     # These are mutually exclusive
     assert not (all_files and files)
@@ -80,6 +87,7 @@ def run_opts(
         verbose=verbose,
         hook=hook,
         remote_branch=remote_branch,
+        local_branch=local_branch,
         from_ref=from_ref,
         to_ref=to_ref,
         remote_name=remote_name,
@@ -88,6 +96,8 @@ def run_opts(
         show_diff_on_failure=show_diff_on_failure,
         commit_msg_filename=commit_msg_filename,
         checkout_type=checkout_type,
+        is_squash_merge=is_squash_merge,
+        rewrite_command=rewrite_command,
     )
 
 
