@@ -1,4 +1,5 @@
 import logging
+import re
 
 import cfgv
 import pytest
@@ -10,6 +11,7 @@ from pre_commit.clientlib import CONFIG_REPO_DICT
 from pre_commit.clientlib import CONFIG_SCHEMA
 from pre_commit.clientlib import DEFAULT_LANGUAGE_VERSION
 from pre_commit.clientlib import MANIFEST_SCHEMA
+from pre_commit.clientlib import META_HOOK_DICT
 from pre_commit.clientlib import MigrateShaToRev
 from pre_commit.clientlib import validate_config_main
 from pre_commit.clientlib import validate_manifest_main
@@ -228,7 +230,8 @@ def test_warn_mutable_rev_invalid(caplog, rev):
             'Mutable references are never updated after first install and are '
             'not supported.  '
             'See https://pre-commit.com/#using-the-latest-version-for-a-repository '  # noqa: E501
-            'for more details.',
+            'for more details.  '
+            'Hint: `pre-commit autoupdate` often fixes this.',
         ),
     ]
 
@@ -244,38 +247,74 @@ def test_warn_mutable_rev_conditional():
         cfgv.validate(config_obj, CONFIG_REPO_DICT)
 
 
-def test_validate_optional_sensible_regex_at_hook_level(caplog):
-    config_obj = {
-        'id': 'flake8',
-        'files': 'dir/*.py',
-    }
-    cfgv.validate(config_obj, CONFIG_HOOK_DICT)
-
-    assert caplog.record_tuples == [
+@pytest.mark.parametrize(
+    ('regex', 'warning'),
+    (
         (
-            'pre_commit',
-            logging.WARNING,
+            r'dir/*.py',
             "The 'files' field in hook 'flake8' is a regex, not a glob -- "
             "matching '/*' probably isn't what you want here",
         ),
-    ]
-
-
-def test_validate_optional_sensible_regex_at_top_level(caplog):
+        (
+            r'dir[\/].*\.py',
+            r"pre-commit normalizes slashes in the 'files' field in hook "
+            r"'flake8' to forward slashes, so you can use / instead of [\/]",
+        ),
+        (
+            r'dir[/\\].*\.py',
+            r"pre-commit normalizes slashes in the 'files' field in hook "
+            r"'flake8' to forward slashes, so you can use / instead of [/\\]",
+        ),
+        (
+            r'dir[\\/].*\.py',
+            r"pre-commit normalizes slashes in the 'files' field in hook "
+            r"'flake8' to forward slashes, so you can use / instead of [\\/]",
+        ),
+    ),
+)
+def test_validate_optional_sensible_regex_at_hook(caplog, regex, warning):
     config_obj = {
-        'files': 'dir/*.py',
+        'id': 'flake8',
+        'files': regex,
+    }
+    cfgv.validate(config_obj, CONFIG_HOOK_DICT)
+
+    assert caplog.record_tuples == [('pre_commit', logging.WARNING, warning)]
+
+
+@pytest.mark.parametrize(
+    ('regex', 'warning'),
+    (
+        (
+            r'dir/*.py',
+            "The top-level 'files' field is a regex, not a glob -- "
+            "matching '/*' probably isn't what you want here",
+        ),
+        (
+            r'dir[\/].*\.py',
+            r"pre-commit normalizes the slashes in the top-level 'files' "
+            r'field to forward slashes, so you can use / instead of [\/]',
+        ),
+        (
+            r'dir[/\\].*\.py',
+            r"pre-commit normalizes the slashes in the top-level 'files' "
+            r'field to forward slashes, so you can use / instead of [/\\]',
+        ),
+        (
+            r'dir[\\/].*\.py',
+            r"pre-commit normalizes the slashes in the top-level 'files' "
+            r'field to forward slashes, so you can use / instead of [\\/]',
+        ),
+    ),
+)
+def test_validate_optional_sensible_regex_at_top_level(caplog, regex, warning):
+    config_obj = {
+        'files': regex,
         'repos': [],
     }
     cfgv.validate(config_obj, CONFIG_SCHEMA)
 
-    assert caplog.record_tuples == [
-        (
-            'pre_commit',
-            logging.WARNING,
-            "The top-level 'files' field is a regex, not a glob -- matching "
-            "'/*' probably isn't what you want here",
-        ),
-    ]
+    assert caplog.record_tuples == [('pre_commit', logging.WARNING, warning)]
 
 
 @pytest.mark.parametrize('fn', (validate_config_main, validate_manifest_main))
@@ -384,6 +423,13 @@ def test_migrate_to_sha_ok():
         {'repo': 'meta', 'hooks': [{'id': 'identity', 'language': 'python'}]},
         # name override must be string
         {'repo': 'meta', 'hooks': [{'id': 'identity', 'name': False}]},
+        pytest.param(
+            {
+                'repo': 'meta',
+                'hooks': [{'id': 'identity', 'entry': 'echo hi'}],
+            },
+            id='cannot override entry for meta hooks',
+        ),
     ),
 )
 def test_meta_hook_invalid(config_repo):
@@ -391,6 +437,15 @@ def test_meta_hook_invalid(config_repo):
         cfgv.validate(config_repo, CONFIG_REPO_DICT)
 
 
+def test_meta_check_hooks_apply_only_at_top_level():
+    cfg = {'id': 'check-hooks-apply'}
+    cfg = cfgv.apply_defaults(cfg, META_HOOK_DICT)
+
+    files_re = re.compile(cfg['files'])
+    assert files_re.search('.pre-commit-config.yaml')
+    assert not files_re.search('foo/.pre-commit-config.yaml')
+
+
 @pytest.mark.parametrize(
     'mapping',
     (
@@ -426,7 +481,7 @@ def test_minimum_pre_commit_version_passing():
 @pytest.mark.parametrize('schema', (CONFIG_SCHEMA, CONFIG_REPO_DICT))
 def test_warn_additional(schema):
     allowed_keys = {item.key for item in schema.items if hasattr(item, 'key')}
-    warn_additional, = [
+    warn_additional, = (
         x for x in schema.items if isinstance(x, cfgv.WarnAdditionalKeys)
-    ]
+    )
     assert allowed_keys == set(warn_additional.keys)
