@@ -1,19 +1,15 @@
 import os.path
 import re
-import sys
-from unittest import mock
 
 import re_assert
 
 import pre_commit.constants as C
 from pre_commit import git
-from pre_commit.commands import install_uninstall
 from pre_commit.commands.install_uninstall import CURRENT_HASH
 from pre_commit.commands.install_uninstall import install
 from pre_commit.commands.install_uninstall import install_hooks
 from pre_commit.commands.install_uninstall import is_our_script
 from pre_commit.commands.install_uninstall import PRIOR_HASHES
-from pre_commit.commands.install_uninstall import shebang
 from pre_commit.commands.install_uninstall import uninstall
 from pre_commit.parse_shebang import find_executable
 from pre_commit.util import cmd_output
@@ -39,47 +35,10 @@ def test_is_script():
 
 def test_is_previous_pre_commit(tmpdir):
     f = tmpdir.join('foo')
-    f.write(f'{PRIOR_HASHES[0]}\n')
+    f.write(f'{PRIOR_HASHES[0].decode()}\n')
     assert is_our_script(f.strpath)
 
 
-def patch_platform(platform):
-    return mock.patch.object(sys, 'platform', platform)
-
-
-def patch_lookup_path(path):
-    return mock.patch.object(install_uninstall, 'POSIX_SEARCH_PATH', path)
-
-
-def patch_sys_exe(exe):
-    return mock.patch.object(install_uninstall, 'SYS_EXE', exe)
-
-
-def test_shebang_windows():
-    with patch_platform('win32'), patch_sys_exe('python'):
-        assert shebang() == '#!/usr/bin/env python'
-
-
-def test_shebang_windows_drop_ext():
-    with patch_platform('win32'), patch_sys_exe('python.exe'):
-        assert shebang() == '#!/usr/bin/env python'
-
-
-def test_shebang_posix_not_on_path():
-    with patch_platform('posix'), patch_lookup_path(()):
-        with patch_sys_exe('python3.6'):
-            assert shebang() == '#!/usr/bin/env python3.6'
-
-
-def test_shebang_posix_on_path(tmpdir):
-    exe = tmpdir.join(f'python{sys.version_info[0]}').ensure()
-    make_executable(exe)
-
-    with patch_platform('posix'), patch_lookup_path((tmpdir.strpath,)):
-        with patch_sys_exe('python'):
-            assert shebang() == f'#!/usr/bin/env python{sys.version_info[0]}'
-
-
 def test_install_pre_commit(in_git_dir, store):
     assert not install(C.CONFIG_FILE, store, hook_types=['pre-commit'])
     assert os.access(in_git_dir.join('.git/hooks/pre-commit').strpath, os.X_OK)
@@ -259,7 +218,10 @@ def _path_without_us():
     exe = find_executable('pre-commit', _environ=env)
     while exe:
         parts = env['PATH'].split(os.pathsep)
-        after = [x for x in parts if x.lower() != os.path.dirname(exe).lower()]
+        after = [
+            x for x in parts
+            if x.lower().rstrip(os.sep) != os.path.dirname(exe).lower()
+        ]
         if parts == after:
             raise AssertionError(exe, parts)
         env['PATH'] = os.pathsep.join(after)
@@ -275,11 +237,7 @@ def test_environment_not_sourced(tempdir_factory, store):
         hook = os.path.join(path, '.git/hooks/pre-commit')
         with open(hook) as f:
             src = f.read()
-        src = re.sub(
-            '\nINSTALL_PYTHON =.*\n',
-            '\nINSTALL_PYTHON = "/dne"\n',
-            src,
-        )
+        src = re.sub('\nINSTALL_PYTHON=.*\n', '\nINSTALL_PYTHON="/dne"\n', src)
         with open(hook, 'w') as f:
             f.write(src)
 
@@ -337,7 +295,7 @@ EXISTING_COMMIT_RUN = re_assert.Matches(
 def _write_legacy_hook(path):
     os.makedirs(os.path.join(path, '.git/hooks'), exist_ok=True)
     with open(os.path.join(path, '.git/hooks/pre-commit'), 'w') as f:
-        f.write(f'{shebang()}\nprint("legacy hook")\n')
+        f.write('#!/usr/bin/env bash\necho legacy hook\n')
     make_executable(f.name)
 
 
@@ -387,6 +345,19 @@ def test_install_existing_hook_no_overwrite_idempotent(tempdir_factory, store):
         NORMAL_PRE_COMMIT_RUN.assert_matches(output[len('legacy hook\n'):])
 
 
+def test_install_with_existing_non_utf8_script(tmpdir, store):
+    cmd_output('git', 'init', str(tmpdir))
+    tmpdir.join('.git/hooks').ensure_dir()
+    tmpdir.join('.git/hooks/pre-commit').write_binary(
+        b'#!/usr/bin/env bash\n'
+        b'# garbage: \xa0\xef\x12\xf2\n'
+        b'echo legacy hook\n',
+    )
+
+    with tmpdir.as_cwd():
+        assert install(C.CONFIG_FILE, store, hook_types=['pre-commit']) == 0
+
+
 FAIL_OLD_HOOK = re_assert.Matches(
     r'fail!\n'
     r'\[INFO\] Initializing environment for .+\.\n'
@@ -457,7 +428,7 @@ def test_replace_old_commit_script(tempdir_factory, store):
         # Install a script that looks like our old script
         pre_commit_contents = resource_text('hook-tmpl')
         new_contents = pre_commit_contents.replace(
-            CURRENT_HASH, PRIOR_HASHES[-1],
+            CURRENT_HASH.decode(), PRIOR_HASHES[-1].decode(),
         )
 
         os.makedirs(os.path.join(path, '.git/hooks'), exist_ok=True)
@@ -759,6 +730,77 @@ def test_post_commit_integration(tempdir_factory, store):
         assert os.path.exists('post-commit.tmp')
 
 
+def test_post_merge_integration(tempdir_factory, store):
+    path = git_dir(tempdir_factory)
+    config = [
+        {
+            'repo': 'local',
+            'hooks': [{
+                'id': 'post-merge',
+                'name': 'Post merge',
+                'entry': 'touch post-merge.tmp',
+                'language': 'system',
+                'always_run': True,
+                'verbose': True,
+                'stages': ['post-merge'],
+            }],
+        },
+    ]
+    write_config(path, config)
+    with cwd(path):
+        #  create a simple diamond of commits for a non-trivial merge
+        open('init', 'a').close()
+        cmd_output('git', 'add', '.')
+        git_commit()
+
+        open('master', 'a').close()
+        cmd_output('git', 'add', '.')
+        git_commit()
+
+        cmd_output('git', 'checkout', '-b', 'branch', 'HEAD^')
+        open('branch', 'a').close()
+        cmd_output('git', 'add', '.')
+        git_commit()
+
+        cmd_output('git', 'checkout', 'master')
+        install(C.CONFIG_FILE, store, hook_types=['post-merge'])
+        retc, stdout, stderr = cmd_output_mocked_pre_commit_home(
+            'git', 'merge', 'branch',
+            tempdir_factory=tempdir_factory,
+        )
+        assert retc == 0
+        assert os.path.exists('post-merge.tmp')
+
+
+def test_post_rewrite_integration(tempdir_factory, store):
+    path = git_dir(tempdir_factory)
+    config = [
+        {
+            'repo': 'local',
+            'hooks': [{
+                'id': 'post-rewrite',
+                'name': 'Post rewrite',
+                'entry': 'touch post-rewrite.tmp',
+                'language': 'system',
+                'always_run': True,
+                'verbose': True,
+                'stages': ['post-rewrite'],
+            }],
+        },
+    ]
+    write_config(path, config)
+    with cwd(path):
+        open('init', 'a').close()
+        cmd_output('git', 'add', '.')
+        install(C.CONFIG_FILE, store, hook_types=['post-rewrite'])
+        git_commit()
+
+        assert not os.path.exists('post-rewrite.tmp')
+
+        git_commit('--amend', '-m', 'ammended message')
+        assert os.path.exists('post-rewrite.tmp')
+
+
 def test_post_checkout_integration(tempdir_factory, store):
     path = git_dir(tempdir_factory)
     config = [
@@ -890,7 +932,7 @@ def test_pre_merge_commit_integration(tempdir_factory, store):
     output_pattern = re_assert.Matches(
         r'^\[INFO\] Initializing environment for .+\n'
         r'Bash hook\.+Passed\n'
-        r"Merge made by the 'recursive' strategy.\n"
+        r"Merge made by the '(ort|recursive)' strategy.\n"
         r' foo \| 0\n'
         r' 1 file changed, 0 insertions\(\+\), 0 deletions\(-\)\n'
         r' create mode 100644 foo\n$',
