@@ -487,6 +487,7 @@ def test_all_push_options_ok(cap_out, store, repo_with_passing_hook):
     args = run_opts(
         from_ref='master', to_ref='master',
         remote_branch='master',
+        local_branch='master',
         remote_name='origin', remote_url='https://example.com/repo',
     )
     ret, printed = _do_run(cap_out, store, repo_with_passing_hook, args)
@@ -494,6 +495,24 @@ def test_all_push_options_ok(cap_out, store, repo_with_passing_hook):
     assert b'Specify both --from-ref and --to-ref.' not in printed
 
 
+def test_is_squash_merge(cap_out, store, repo_with_passing_hook):
+    args = run_opts(is_squash_merge='1')
+    environ: MutableMapping[str, str] = {}
+    ret, printed = _do_run(
+        cap_out, store, repo_with_passing_hook, args, environ,
+    )
+    assert environ['PRE_COMMIT_IS_SQUASH_MERGE'] == '1'
+
+
+def test_rewrite_command(cap_out, store, repo_with_passing_hook):
+    args = run_opts(rewrite_command='amend')
+    environ: MutableMapping[str, str] = {}
+    ret, printed = _do_run(
+        cap_out, store, repo_with_passing_hook, args, environ,
+    )
+    assert environ['PRE_COMMIT_REWRITE_COMMAND'] == 'amend'
+
+
 def test_checkout_type(cap_out, store, repo_with_passing_hook):
     args = run_opts(from_ref='', to_ref='', checkout_type='1')
     environ: MutableMapping[str, str] = {}
@@ -517,9 +536,9 @@ def test_merge_conflict(cap_out, store, in_merge_conflict):
 
 def test_merge_conflict_modified(cap_out, store, in_merge_conflict):
     # Touch another file so we have unstaged non-conflicting things
-    assert os.path.exists('dummy')
-    with open('dummy', 'w') as dummy_file:
-        dummy_file.write('bar\nbaz\n')
+    assert os.path.exists('placeholder')
+    with open('placeholder', 'w') as placeholder_file:
+        placeholder_file.write('bar\nbaz\n')
 
     ret, printed = _do_run(cap_out, store, in_merge_conflict, run_opts())
     assert ret == 1
@@ -591,6 +610,29 @@ def test_skip_aliased_hook(cap_out, store, aliased_repo):
         assert printed.count(msg) == 1
 
 
+def test_skip_bypasses_installation(cap_out, store, repo_with_passing_hook):
+    config = {
+        'repo': 'local',
+        'hooks': [
+            {
+                'id': 'skipme',
+                'name': 'skipme',
+                'entry': 'skipme',
+                'language': 'python',
+                'additional_dependencies': ['/pre-commit-does-not-exist'],
+            },
+        ],
+    }
+    add_config_to_repo(repo_with_passing_hook, config)
+
+    ret, printed = _do_run(
+        cap_out, store, repo_with_passing_hook,
+        run_opts(all_files=True),
+        {'SKIP': 'skipme'},
+    )
+    assert ret == 0
+
+
 def test_hook_id_not_in_non_verbose_output(
         cap_out, store, repo_with_passing_hook,
 ):
@@ -799,9 +841,9 @@ def test_local_hook_passes(cap_out, store, repo_with_passing_hook):
     }
     add_config_to_repo(repo_with_passing_hook, config)
 
-    with open('dummy.py', 'w') as staged_file:
+    with open('placeholder.py', 'w') as staged_file:
         staged_file.write('"""TODO: something"""\n')
-    cmd_output('git', 'add', 'dummy.py')
+    cmd_output('git', 'add', 'placeholder.py')
 
     _test_run(
         cap_out,
@@ -826,9 +868,9 @@ def test_local_hook_fails(cap_out, store, repo_with_passing_hook):
     }
     add_config_to_repo(repo_with_passing_hook, config)
 
-    with open('dummy.py', 'w') as staged_file:
+    with open('placeholder.py', 'w') as staged_file:
         staged_file.write('"""TODO: something"""\n')
-    cmd_output('git', 'add', 'dummy.py')
+    cmd_output('git', 'add', 'placeholder.py')
 
     _test_run(
         cap_out,
@@ -943,6 +985,18 @@ def test_fail_fast(cap_out, store, repo_with_failing_hook):
     assert printed.count(b'Failing hook') == 1
 
 
+def test_fail_fast_per_hook(cap_out, store, repo_with_failing_hook):
+    with modify_config() as config:
+        # More than one hook
+        config['repos'][0]['hooks'] *= 2
+        config['repos'][0]['hooks'][0]['fail_fast'] = True
+    stage_a_file()
+
+    ret, printed = _do_run(cap_out, store, repo_with_failing_hook, run_opts())
+    # it should have only run one hook
+    assert printed.count(b'Failing hook') == 1
+
+
 def test_classifier_removes_dne():
     classifier = Classifier(('this_file_does_not_exist',))
     assert classifier.filenames == []
