@@ -38,6 +38,17 @@ def test_get_root_bare_worktree(tmpdir):
         assert git.get_root() == os.path.abspath('.')
 
 
+def test_get_root_worktree_in_git(tmpdir):
+    src = tmpdir.join('src').ensure_dir()
+    cmd_output('git', 'init', str(src))
+    git_commit(cwd=str(src))
+
+    cmd_output('git', 'worktree', 'add', '.git/trees/foo', 'HEAD', cwd=src)
+
+    with src.join('.git/trees/foo').as_cwd():
+        assert git.get_root() == os.path.abspath('.')
+
+
 def test_get_staged_files_deleted(in_git_dir):
     in_git_dir.join('test').ensure()
     cmd_output('git', 'add', 'test')
@@ -128,6 +139,24 @@ def test_get_changed_files(in_git_dir):
     assert files == []
 
 
+def test_get_changed_files_disparate_histories(in_git_dir):
+    """in modern versions of git, `...` does not fall back to full diff"""
+    git_commit()
+    in_git_dir.join('a.txt').ensure()
+    cmd_output('git', 'add', '.')
+    git_commit()
+    cmd_output('git', 'branch', '-m', 'branch1')
+
+    cmd_output('git', 'checkout', '--orphan', 'branch2')
+    cmd_output('git', 'rm', '-rf', '.')
+    in_git_dir.join('a.txt').ensure()
+    in_git_dir.join('b.txt').ensure()
+    cmd_output('git', 'add', '.')
+    git_commit()
+
+    assert git.get_changed_files('branch1', 'branch2') == ['b.txt']
+
+
 @pytest.mark.parametrize(
     ('s', 'expected'),
     (
@@ -198,6 +227,11 @@ def test_no_git_env():
         'GIT_SSH': '/usr/bin/ssh',
         'GIT_SSH_COMMAND': 'ssh -o',
         'GIT_DIR': '/none/shall/pass',
+        'GIT_CONFIG_KEY_0': 'user.name',
+        'GIT_CONFIG_VALUE_0': 'anthony',
+        'GIT_CONFIG_KEY_1': 'user.email',
+        'GIT_CONFIG_VALUE_1': 'asottile@example.com',
+        'GIT_CONFIG_COUNT': '2',
     }
     no_git_env = git.no_git_env(env)
     assert no_git_env == {
@@ -205,6 +239,11 @@ def test_no_git_env():
         'GIT_EXEC_PATH': '/some/git/exec/path',
         'GIT_SSH': '/usr/bin/ssh',
         'GIT_SSH_COMMAND': 'ssh -o',
+        'GIT_CONFIG_KEY_0': 'user.name',
+        'GIT_CONFIG_VALUE_0': 'anthony',
+        'GIT_CONFIG_KEY_1': 'user.email',
+        'GIT_CONFIG_VALUE_1': 'asottile@example.com',
+        'GIT_CONFIG_COUNT': '2',
     }
 
 
