@@ -1,4 +1,5 @@
 import os.path
+import tarfile
 from unittest import mock
 
 import pytest
@@ -8,6 +9,7 @@ from pre_commit import parse_shebang
 from pre_commit.languages import ruby
 from pre_commit.prefix import Prefix
 from pre_commit.util import cmd_output
+from pre_commit.util import resource_bytesio
 from testing.util import xfailif_windows
 
 
@@ -34,13 +36,13 @@ def test_uses_system_if_both_gem_and_ruby_are_available(find_exe_mck):
 def fake_gem_prefix(tmpdir):
     gemspec = '''\
 Gem::Specification.new do |s|
-    s.name = 'pre_commit_dummy_package'
+    s.name = 'pre_commit_placeholder_package'
     s.version = '0.0.0'
-    s.summary = 'dummy gem for pre-commit hooks'
+    s.summary = 'placeholder gem for pre-commit hooks'
     s.authors = ['Anthony Sottile']
 end
 '''
-    tmpdir.join('dummy_gem.gemspec').write(gemspec)
+    tmpdir.join('placeholder_gem.gemspec').write(gemspec)
     yield Prefix(tmpdir)
 
 
@@ -51,7 +53,7 @@ def test_install_ruby_system(fake_gem_prefix):
     # Should be able to activate and use rbenv install
     with ruby.in_env(fake_gem_prefix, 'system'):
         _, out, _ = cmd_output('gem', 'list')
-        assert 'pre_commit_dummy_package' in out
+        assert 'pre_commit_placeholder_package' in out
 
 
 @xfailif_windows  # pragma: win32 no cover
@@ -72,3 +74,14 @@ def test_install_ruby_with_version(fake_gem_prefix):
     # Should be able to activate and use rbenv install
     with ruby.in_env(fake_gem_prefix, '2.7.2'):
         cmd_output('rbenv', 'install', '--help')
+
+
+@pytest.mark.parametrize(
+    'filename',
+    ('rbenv.tar.gz', 'ruby-build.tar.gz', 'ruby-download.tar.gz'),
+)
+def test_archive_root_stat(filename):
+    with resource_bytesio(filename) as f:
+        with tarfile.open(fileobj=f) as tarf:
+            root, _, _ = filename.partition('.')
+            assert oct(tarf.getmember(root).mode) == '0o755'
