@@ -34,6 +34,7 @@ from testing.util import cwd
 from testing.util import get_resource_path
 from testing.util import skipif_cant_run_coursier
 from testing.util import skipif_cant_run_docker
+from testing.util import skipif_cant_run_lua
 from testing.util import skipif_cant_run_swift
 from testing.util import xfailif_windows
 
@@ -51,7 +52,7 @@ def _get_hook_no_install(repo_config, store, hook_id):
     config = cfgv.validate(config, CONFIG_SCHEMA)
     config = cfgv.apply_defaults(config, CONFIG_SCHEMA)
     hooks = all_hooks(config, store)
-    hook, = [hook for hook in hooks if hook.id == hook_id]
+    hook, = (hook for hook in hooks if hook.id == hook_id)
     return hook
 
 
@@ -111,8 +112,8 @@ def test_local_conda_additional_dependencies(store):
             'name': 'local-conda',
             'entry': 'python',
             'language': 'conda',
-            'args': ['-c', 'import tzdata; print("OK")'],
-            'additional_dependencies': ['python-tzdata'],
+            'args': ['-c', 'import botocore; print("OK")'],
+            'additional_dependencies': ['botocore'],
         }],
     }
     hook = _get_hook(config, store, 'local-conda')
@@ -164,7 +165,7 @@ def test_python_hook_weird_setup_cfg(in_git_dir, tempdir_factory, store):
     )
 
 
-def test_python_venv(tempdir_factory, store):  # pragma: no cover (no venv)
+def test_python_venv(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'python_venv_hooks_repo',
         'foo', [os.devnull],
@@ -245,7 +246,6 @@ def test_run_a_docker_image_hook(tempdir_factory, store, hook_id):
     )
 
 
-@xfailif_windows  # pragma: win32 no cover
 def test_run_a_node_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'node_hooks_repo',
@@ -253,7 +253,6 @@ def test_run_a_node_hook(tempdir_factory, store):
     )
 
 
-@xfailif_windows  # pragma: win32 no cover
 def test_run_a_node_hook_default_version(tempdir_factory, store):
     # make sure that this continues to work for platforms where node is not
     # installed at the system
@@ -263,7 +262,6 @@ def test_run_a_node_hook_default_version(tempdir_factory, store):
         test_run_a_node_hook(tempdir_factory, store)
 
 
-@xfailif_windows  # pragma: win32 no cover
 def test_run_versioned_node_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'node_versioned_hooks_repo',
@@ -271,7 +269,6 @@ def test_run_versioned_node_hook(tempdir_factory, store):
     )
 
 
-@xfailif_windows  # pragma: win32 no cover
 def test_node_hook_with_npm_userconfig_set(tempdir_factory, store, tmpdir):
     cfg = tmpdir.join('cfg')
     cfg.write('cache=/dne\n')
@@ -279,6 +276,54 @@ def test_node_hook_with_npm_userconfig_set(tempdir_factory, store, tmpdir):
         test_run_a_node_hook(tempdir_factory, store)
 
 
+def test_r_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'r_hooks_repo',
+        'hello-world', [os.devnull],
+        b'Hello, World, from R!\n',
+    )
+
+
+def test_r_inline_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'r_hooks_repo',
+        'hello-world-inline', ['some-file'],
+        b'Hi-there, some-file, from R!\n',
+    )
+
+
+def test_r_with_additional_dependencies_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'r_hooks_repo',
+        'additional-deps', [os.devnull],
+        b'OK\n',
+        config_kwargs={
+            'hooks': [{
+                'id': 'additional-deps',
+                'additional_dependencies': ['cachem@1.0.4'],
+            }],
+        },
+    )
+
+
+def test_r_local_with_additional_dependencies_hook(store):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'local-r',
+            'name': 'local-r',
+            'entry': 'Rscript -e',
+            'language': 'r',
+            'args': ['if (packageVersion("R6") == "2.1.3") cat("OK\n")'],
+            'additional_dependencies': ['R6@2.1.3'],
+        }],
+    }
+    hook = _get_hook(config, store, 'local-r')
+    ret, out = _hook_run(hook, (), color=False)
+    assert ret == 0
+    assert _norm_out(out) == b'OK\n'
+
+
 def test_run_a_ruby_hook(tempdir_factory, store):
     _test_hook_repo(
         tempdir_factory, store, 'ruby_hooks_repo',
@@ -605,7 +650,6 @@ def test_additional_ruby_dependencies_installed(tempdir_factory, store):
         assert 'tins' in output
 
 
-@xfailif_windows  # pragma: win32 no cover
 def test_additional_node_dependencies_installed(tempdir_factory, store):
     path = make_repo(tempdir_factory, 'node_hooks_repo')
     config = make_config_from_repo(path)
@@ -953,11 +997,13 @@ def test_manifest_hooks(tempdir_factory, store):
         require_serial=False,
         stages=(
             'commit', 'merge-commit', 'prepare-commit-msg', 'commit-msg',
-            'post-commit', 'manual', 'post-checkout', 'push',
+            'post-commit', 'manual', 'post-checkout', 'push', 'post-merge',
+            'post-rewrite',
         ),
         types=['file'],
         types_or=[],
         verbose=False,
+        fail_fast=False,
     )
 
 
@@ -976,13 +1022,13 @@ def test_local_perl_additional_dependencies(store):
             'name': 'hello',
             'entry': 'perltidy --version',
             'language': 'perl',
-            'additional_dependencies': ['SHANCOCK/Perl-Tidy-20200110.tar.gz'],
+            'additional_dependencies': ['SHANCOCK/Perl-Tidy-20211029.tar.gz'],
         }],
     }
     hook = _get_hook(config, store, 'hello')
     ret, out = _hook_run(hook, (), color=False)
     assert ret == 0
-    assert _norm_out(out).startswith(b'This is perltidy, v20200110')
+    assert _norm_out(out).startswith(b'This is perltidy, v20211029')
 
 
 @pytest.mark.parametrize(
@@ -995,10 +1041,50 @@ def test_local_perl_additional_dependencies(store):
 def test_dotnet_hook(tempdir_factory, store, repo):
     _test_hook_repo(
         tempdir_factory, store, repo,
-        'dotnet example hook', [], b'Hello from dotnet!\n',
+        'dotnet-example-hook', [], b'Hello from dotnet!\n',
     )
 
 
+def test_dart_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'dart_repo',
+        'hello-world-dart', [], b'hello hello world\n',
+    )
+
+
+def test_local_dart_additional_dependencies(store):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'local-dart',
+            'name': 'local-dart',
+            'entry': 'hello-world-dart',
+            'language': 'dart',
+            'additional_dependencies': ['hello_world_dart'],
+        }],
+    }
+    hook = _get_hook(config, store, 'local-dart')
+    ret, out = _hook_run(hook, (), color=False)
+    assert (ret, _norm_out(out)) == (0, b'hello hello world\n')
+
+
+def test_local_dart_additional_dependencies_versioned(store):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'local-dart',
+            'name': 'local-dart',
+            'entry': 'secure-random -l 4 -b 16',
+            'language': 'dart',
+            'additional_dependencies': ['encrypt:5.0.0'],
+        }],
+    }
+    hook = _get_hook(config, store, 'local-dart')
+    ret, out = _hook_run(hook, (), color=False)
+    assert ret == 0
+    re_assert.Matches('^[a-f0-9]{8}\r?\n$').assert_matches(out.decode())
+
+
 def test_non_installable_hook_error_for_language_version(store, caplog):
     config = {
         'repo': 'local',
@@ -1043,3 +1129,29 @@ def test_non_installable_hook_error_for_additional_dependencies(store, caplog):
         'using language `system` which does not install an environment.  '
         'Perhaps you meant to use a specific language?'
     )
+
+
+@skipif_cant_run_lua  # pragma: win32 no cover
+def test_lua_hook(tempdir_factory, store):
+    _test_hook_repo(
+        tempdir_factory, store, 'lua_repo',
+        'hello-world-lua', [], b'hello world\n',
+    )
+
+
+@skipif_cant_run_lua  # pragma: win32 no cover
+def test_local_lua_additional_dependencies(store):
+    config = {
+        'repo': 'local',
+        'hooks': [{
+            'id': 'local-lua',
+            'name': 'local-lua',
+            'entry': 'luacheck --version',
+            'language': 'lua',
+            'additional_dependencies': ['luacheck'],
+        }],
+    }
+    hook = _get_hook(config, store, 'local-lua')
+    ret, out = _hook_run(hook, (), color=False)
+    assert b'Luacheck' in out
+    assert ret == 0
