@@ -160,7 +160,7 @@ def test_xargs_concurrency():
     assert ret == 0
     pids = stdout.splitlines()
     assert len(pids) == 5
-    # It would take 0.5*5=2.5 seconds ot run all of these in serial, so if it
+    # It would take 0.5*5=2.5 seconds to run all of these in serial, so if it
     # takes less, they must have run concurrently.
     assert elapsed < 2.5
 
@@ -195,3 +195,12 @@ def test_xargs_color_true_makes_tty():
     )
     assert retcode == 0
     assert out == b'True\n'
+
+
+@pytest.mark.xfail(os.name == 'posix', reason='nt only')
+@pytest.mark.parametrize('filename', ('t.bat', 't.cmd', 'T.CMD'))
+def test_xargs_with_batch_files(tmpdir, filename):
+    f = tmpdir.join(filename)
+    f.write('echo it works\n')
+    retcode, out = xargs.xargs((str(f),), ('x',) * 8192)
+    assert retcode == 0, (retcode, out)
